@@ -35,26 +35,6 @@ async def process_output(stream: Any, level: int) -> None:
             exec_logger.critical("[EXECUTION] %s %s", type(ex).__name__, ex)
 
 
-async def readline(pipe: Any) -> Tuple[str, Optional[str]]:
-    """-"""
-
-    data = await pipe.readline()
-    if data:
-        line = str(data.decode('ascii').rstrip())
-        if line.strip().startswith("INFO "):
-            line = line.replace("INFO ", "")
-            return ("STDOUT", line)
-        elif line.strip().startswith("ERROR "):
-            line = line.replace("ERROR ", "")
-            return ("STDERR", line)
-        else:
-            if line.strip().startswith("DEBUG "):
-                line = line.replace("DEBUG ", "")
-            return ("PROCESS", line)
-
-    return ("PROCESS", None)
-
-
 def terminate_process(process: Any) -> None:
     """-"""
     try:
@@ -124,7 +104,7 @@ async def run_command(
         program,
         *args,
         stdout=asyncio.subprocess.PIPE,
-        stderr=asyncio.subprocess.PIPE, 
+        stderr=asyncio.subprocess.PIPE,
         creationflags=subprocess.CREATE_NEW_PROCESS_GROUP
     )
 
@@ -153,6 +133,7 @@ async def run_command(
             await asyncio.wait_for(process.wait(), stop_timeout)
         except asyncio.TimeoutError:
             try:
+                print("Stop timeout exceeded, process needs to be killed.", flush=True)
                 process.kill()
             except Exception as ex:  # pylint: disable=broad-except
                 pass
